@@ -9,12 +9,7 @@ import uuid
 import importlib
 import colour_text
 
-# modulefinder is broken in 3.8
-# was the fixed bundled copy
-if sys.version_info.major == 3 and sys.version_info.minor == 8:
-    from . import modulefinder
-else:
-    import modulefinder
+import modulefinder
 
 from . import win_app_package_win_pe_info
 from . import win_app_package_exe_config
@@ -90,6 +85,18 @@ class AppPackage:
         'win32evtlog',
         'win32evtlogutil',
         'asyncio.DefaultEventLoopPolicy',
+
+        # new in python 3.9
+        'pep517',
+        '_testinternalcapi',
+
+        # with python 3.10 and newer packages on PyPI
+        'fcntl',
+        'dateutil',
+        'backports',
+        'backports.zoneinfo',
+        'pytz',
+        'pytz.tzinfo',
         ] )
     all_imported_modules_to_exclude = set( [
         'ctypes',
@@ -171,6 +178,7 @@ class AppPackage:
 ################################################################################
         print(
 '''python3 -m win_app_packager build <main-script> <package-folder> [<options>...]
+
   main-script
     - python main module
   package-folder
@@ -345,11 +353,11 @@ class AppPackage:
             all_missing = set( missing )
             all_missing_but_needed = all_missing - self.all_modules_allowed_to_be_missing
 
-            for x in all_missing_but_needed:
-                self.error( 'Module %s is missing but is required' % (x,) )
+            for module_name in all_missing_but_needed:
+                self.error( 'Module %s is missing but is required' % (module_name,) )
 
-            for x in maybe:
-                self.warning( 'Module %s maybe missing' % (x,) )
+            for module_name in maybe:
+                self.warning( 'Module %s maybe missing' % (module_name,) )
 
             if len(all_missing_but_needed) > 0:
                 return 1
